summaryrefslogtreecommitdiffstats
path: root/tdecore
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-07 20:28:49 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-07 20:28:49 -0600
commit8cfbfac527b65529ac5d96a6255a251769c36634 (patch)
tree75ce025caa285bdfcab9490de8248faedc185770 /tdecore
parent17c857c26eb1254ed0382ed0321c94967826170d (diff)
downloadtdelibs-8cfbfac527b65529ac5d96a6255a251769c36634.tar.gz
tdelibs-8cfbfac527b65529ac5d96a6255a251769c36634.zip
Rename kwin to twin (part 1 of 2)
Diffstat (limited to 'tdecore')
-rw-r--r--tdecore/CMakeLists.txt6
-rw-r--r--tdecore/MAINTAINERS4
-rw-r--r--tdecore/Makefile.am4
-rw-r--r--tdecore/README.kiosk2
-rw-r--r--tdecore/all_languages.desktop2
-rw-r--r--tdecore/kapplication.cpp2
-rw-r--r--tdecore/kapplication.h4
-rw-r--r--tdecore/kdebug.areas6
-rw-r--r--tdecore/kdetcompmgr.cpp4
-rw-r--r--tdecore/knotifyclient.cpp2
-rw-r--r--tdecore/kstartupinfo.cpp4
-rw-r--r--tdecore/kuniqueapplication.cpp2
-rw-r--r--tdecore/kwin.cpp24
-rw-r--r--tdecore/kwin.h2
-rw-r--r--tdecore/kwinmodule.cpp14
-rw-r--r--tdecore/kwinmodule.h4
-rw-r--r--tdecore/tests/kstddirstest.cpp4
17 files changed, 45 insertions, 45 deletions
diff --git a/tdecore/CMakeLists.txt b/tdecore/CMakeLists.txt
index 348e80451..c82e25408 100644
--- a/tdecore/CMakeLists.txt
+++ b/tdecore/CMakeLists.txt
@@ -48,8 +48,8 @@ install( FILES
kurl.h ksock.h kaboutdata.h kcmdlineargs.h kconfigbackend.h
kapp.h kapplication.h kuniqueapp.h kuniqueapplication.h
kcharsets.h kdeversion.h kpty.h kprocess.h kprocctrl.h
- klocale.h kicontheme.h kiconloader.h kdebug.h kwinmodule.h
- kwin.h krootprop.h kshortcut.h kkeynative.h kaccel.h
+ klocale.h kicontheme.h kiconloader.h kdebug.h twinmodule.h
+ twin.h krootprop.h kshortcut.h kkeynative.h kaccel.h
kglobalaccel.h kstdaccel.h kshortcutlist.h kcatalogue.h
kregexp.h kcompletion.h kstringhandler.h kstddirs.h
kstandarddirs.h kglobal.h kglobalsettings.h ksharedptr.h
@@ -98,7 +98,7 @@ set( ${target}_SRCS
kmanagerselection.cpp kdesktopfile.cpp kstandarddirs.cpp
ksock.cpp kpty.cpp kprocess.cpp kprocctrl.cpp klocale.cpp
krfcdate.cpp kiconeffect.cpp kicontheme.cpp kiconloader.cpp
- kwin.cpp kwinmodule.cpp krootprop.cpp kcharsets.cpp
+ twin.cpp twinmodule.cpp krootprop.cpp kcharsets.cpp
kckey.cpp kshortcut.cpp kkeynative_x11.cpp kkeyserver_x11.cpp
kaccelaction.cpp kshortcutmenu.cpp kaccelbase.cpp kaccel.cpp
kglobalaccel_x11.cpp kglobalaccel.cpp kstdaccel.cpp kshortcutlist.cpp
diff --git a/tdecore/MAINTAINERS b/tdecore/MAINTAINERS
index 64b825f06..c052a36d6 100644
--- a/tdecore/MAINTAINERS
+++ b/tdecore/MAINTAINERS
@@ -71,8 +71,8 @@ ktempfile.cpp Waldo Bastian <bastian@kde.org>
kuniqueapplication.cpp Waldo Bastian <bastian@kde.org>
kurl.cpp Waldo Bastian <bastian@kde.org>
kurldrag.cpp David Faure <faure@kde.org>
-kwin.cpp Lubos Lunak <l.lunak@kde.org>
-kwinmodule.cpp Lubos Lunak <l.lunak@kde.org>
+twin.cpp Lubos Lunak <l.lunak@kde.org>
+twinmodule.cpp Lubos Lunak <l.lunak@kde.org>
kxmessages.cpp Lubos Lunak <l.lunak@kde.org>
kxerrorhandler.cpp Lubos Lunak <l.lunak@kde.org>
libintl.cpp Hans Petter Bieker <bieker@kde.org>
diff --git a/tdecore/Makefile.am b/tdecore/Makefile.am
index 92ee7ebfc..a9c44ee15 100644
--- a/tdecore/Makefile.am
+++ b/tdecore/Makefile.am
@@ -42,7 +42,7 @@ include_HEADERS = kconfig.h kconfigskeleton.h \
kcmdlineargs.h kconfigbackend.h kapp.h kapplication.h kuniqueapp.h \
kuniqueapplication.h kcharsets.h kdeversion.h kpty.h kprocess.h \
kprocctrl.h klocale.h kicontheme.h kiconloader.h kdebug.h \
- kwinmodule.h kwin.h krootprop.h kshortcut.h kkeynative.h kaccel.h \
+ twinmodule.h twin.h krootprop.h kshortcut.h kkeynative.h kaccel.h \
kglobalaccel.h kstdaccel.h kshortcutlist.h kcatalogue.h \
kregexp.h kcompletion.h kstringhandler.h \
kstddirs.h kstandarddirs.h kglobal.h kglobalsettings.h ksharedptr.h \
@@ -94,7 +94,7 @@ libtdecore_la_SOURCES = libintl.cpp kapplication.cpp \
kconfigbackend.cpp kmanagerselection.cpp kdesktopfile.cpp \
kstandarddirs.cpp ksock.cpp kpty.cpp kprocess.cpp kprocctrl.cpp \
klocale.cpp krfcdate.cpp kiconeffect.cpp kicontheme.cpp \
- kiconloader.cpp kwin.cpp kwinmodule.cpp krootprop.cpp kcharsets.cpp \
+ kiconloader.cpp twin.cpp twinmodule.cpp krootprop.cpp kcharsets.cpp \
kckey.cpp kshortcut.cpp kkeynative_x11.cpp kkeyserver_x11.cpp \
kaccelaction.cpp kshortcutmenu.cpp kaccelbase.cpp kaccel.cpp \
kglobalaccel_x11.cpp kglobalaccel.cpp kstdaccel.cpp kshortcutlist.cpp \
diff --git a/tdecore/README.kiosk b/tdecore/README.kiosk
index cd59f8db3..257c5a446 100644
--- a/tdecore/README.kiosk
+++ b/tdecore/README.kiosk
@@ -239,7 +239,7 @@ action/menuedit
KWin related:
-action/kwin_rmb // RMB window context menu
+action/twin_rmb // RMB window context menu
Konsole related:
action/konsole_rmb // RMB context menu
diff --git a/tdecore/all_languages.desktop b/tdecore/all_languages.desktop
index 2f36efff6..3c3483ee8 100644
--- a/tdecore/all_languages.desktop
+++ b/tdecore/all_languages.desktop
@@ -1648,7 +1648,7 @@ Name[gl]=Eslávo Eclesiástico
Name[he]=סלבית כנסייתית
Name[hi]=चर्च स्लाविक
Name[hr]=Crkveni pravoslavni
-Name[hsb]=Cyrkwinosłowjansce
+Name[hsb]=Cyrtwinosłowjansce
Name[hu]=Szláv (egyházi)
Name[is]=Kirkju-slavneska
Name[it]=Slavo della Chiesa
diff --git a/tdecore/kapplication.cpp b/tdecore/kapplication.cpp
index 6fad03069..b56f683ea 100644
--- a/tdecore/kapplication.cpp
+++ b/tdecore/kapplication.cpp
@@ -104,7 +104,7 @@
#include <sys/types.h>
#ifndef Q_WS_WIN
-#include "kwin.h"
+#include "twin.h"
#endif
#include <fcntl.h>
diff --git a/tdecore/kapplication.h b/tdecore/kapplication.h
index bec523a0b..014b1cad5 100644
--- a/tdecore/kapplication.h
+++ b/tdecore/kapplication.h
@@ -1078,7 +1078,7 @@ public:
/**
* Updates the last user action timestamp to the given time, or to the current time,
* if 0 is given. Do not use unless you're really sure what you're doing.
- * Consult focus stealing prevention section in kdebase/kwin/README.
+ * Consult focus stealing prevention section in kdebase/twin/README.
* @since 3.2
*/
void updateUserTimestamp( unsigned long time = 0 );
@@ -1095,7 +1095,7 @@ public:
* to the given time, or to this application's user time, if 0 is given.
* Use before causing user interaction in the remote application, e.g. invoking a dialog
* in the application using a DCOP call.
- * Consult focus stealing prevention section in kdebase/kwin/README.
+ * Consult focus stealing prevention section in kdebase/twin/README.
* @since 3.3
*/
void updateRemoteUserTimestamp( const TQCString& dcopId, unsigned long time = 0 );
diff --git a/tdecore/kdebug.areas b/tdecore/kdebug.areas
index efa46034c..03f7a8c95 100644
--- a/tdecore/kdebug.areas
+++ b/tdecore/kdebug.areas
@@ -80,11 +80,11 @@
1208 kcontrol
1210 kicker
1211 konsole
-1212 kwin
+1212 twin
1213 kappfinder
1214 kdesktop (icons)
1215 ksysguard
-1216 kwin (client errors)
+1216 twin (client errors)
1217 khotkeys
1218 ksmserver
1219 media kioslave
@@ -360,7 +360,7 @@
12007 kolf
12008 kbounce
12009 kblackbox
-12010 kwin4
+12010 twin4
12011 kenolaba
12012 kasteroids
diff --git a/tdecore/kdetcompmgr.cpp b/tdecore/kdetcompmgr.cpp
index 9b78e3478..d989bbe19 100644
--- a/tdecore/kdetcompmgr.cpp
+++ b/tdecore/kdetcompmgr.cpp
@@ -51,7 +51,7 @@ int main(int argc, char **argv)
KApplication app;
- KConfig config("kwinrc", true);
+ KConfig config("twinrc", true);
config.setGroup( "Notification Messages" );
if (!config.readBoolEntry("UseTranslucency",false)) {
// Attempt to load the kompmgr pid file
@@ -100,7 +100,7 @@ int main(int argc, char **argv)
// app.detectCompositionManagerAvailable();
// if (!app.isCompositionManagerAvailable()) {
- KConfig config2("kwinrc", true);
+ KConfig config2("twinrc", true);
config2.setGroup( "Notification Messages" );
if (config2.readBoolEntry("UseTranslucency",false)) {
app.detectCompositionManagerAvailable(true, true);
diff --git a/tdecore/knotifyclient.cpp b/tdecore/knotifyclient.cpp
index 185639f11..e146fec85 100644
--- a/tdecore/knotifyclient.cpp
+++ b/tdecore/knotifyclient.cpp
@@ -38,7 +38,7 @@ static bool canAvoidStartupEvent( const TQString& event, const TQString& appname
static bool checkAvoid = true;
if( !checkAvoid )
return false;
- if(( appname != "kwin" && appname != "ksmserver" ) || present > 0 ) {
+ if(( appname != "twin" && appname != "ksmserver" ) || present > 0 ) {
checkAvoid = false;
return false;
}
diff --git a/tdecore/kstartupinfo.cpp b/tdecore/kstartupinfo.cpp
index 12825e805..ae3b3d277 100644
--- a/tdecore/kstartupinfo.cpp
+++ b/tdecore/kstartupinfo.cpp
@@ -58,9 +58,9 @@ DEALINGS IN THE SOFTWARE.
#include <kapplication.h>
#include <signal.h>
#ifdef Q_WS_X11
-#include <kwinmodule.h>
+#include <twinmodule.h>
#include <kxmessages.h>
-#include <kwin.h>
+#include <twin.h>
#endif
static const char* const NET_STARTUP_MSG = "_NET_STARTUP_INFO";
diff --git a/tdecore/kuniqueapplication.cpp b/tdecore/kuniqueapplication.cpp
index 193aafcd3..686f40e86 100644
--- a/tdecore/kuniqueapplication.cpp
+++ b/tdecore/kuniqueapplication.cpp
@@ -39,7 +39,7 @@
#include <kaboutdata.h>
#if defined Q_WS_X11
-#include <kwin.h>
+#include <twin.h>
#include <kstartupinfo.h>
#endif
diff --git a/tdecore/kwin.cpp b/tdecore/kwin.cpp
index fa68da63c..0e5db11b1 100644
--- a/tdecore/kwin.cpp
+++ b/tdecore/kwin.cpp
@@ -34,7 +34,7 @@
#include <tqdialog.h>
#include "config.h"
-#include "kwin.h"
+#include "twin.h"
#include "kapplication.h"
#include <kglobal.h>
@@ -62,10 +62,10 @@ static Atom net_wm_context_help;
static Atom kde_wm_change_state;
static Atom kde_wm_window_opacity;
static Atom kde_wm_window_shadow;
-static Atom kwin_UTF8_STRING;
+static Atom twin_UTF8_STRING;
static Atom net_wm_cm;
-static void kwin_net_create_atoms() {
+static void twin_net_create_atoms() {
if (!atoms_created){
const int max = 20;
Atom* atoms[max];
@@ -146,7 +146,7 @@ static void sendClientMessage(Window w, Atom a, long x){
bool KWin::compositingActive()
{
#ifdef Q_WS_X11
- kwin_net_create_atoms();
+ twin_net_create_atoms();
return XGetSelectionOwner( qt_xdisplay(), net_wm_cm ) != None;
#else
return false;
@@ -166,7 +166,7 @@ public:
ContextWidget::ContextWidget()
: TQWidget(0,0)
{
- kwin_net_create_atoms();
+ twin_net_create_atoms();
kapp->installX11EventFilter( this );
TQWhatsThis::enterWhatsThisMode();
TQCursor c = *TQApplication::overrideCursor();
@@ -561,7 +561,7 @@ void KWin::clearState( WId win, unsigned long state )
void KWin::setOpacity( WId win, uint percent )
{
#ifdef Q_WS_X11
- kwin_net_create_atoms();
+ twin_net_create_atoms();
if (percent > 99)
XDeleteProperty (qt_xdisplay(), win, kde_wm_window_opacity);
else
@@ -575,7 +575,7 @@ void KWin::setOpacity( WId win, uint percent )
void KWin::setShadowSize( WId win, uint percent )
{
#ifdef Q_WS_X11
- kwin_net_create_atoms();
+ twin_net_create_atoms();
long shadowSize = long(0xFFFFFFFF/100.0*percent);
XChangeProperty(qt_xdisplay(), win, kde_wm_window_shadow, XA_CARDINAL, 32, PropModeReplace, (unsigned char *) &shadowSize, 1L);
#endif
@@ -686,7 +686,7 @@ void KWin::iconifyWindow( WId win, bool animation)
#ifdef Q_WS_X11
if ( !animation )
{
- kwin_net_create_atoms();
+ twin_net_create_atoms();
sendClientMessageToRoot( win, kde_wm_change_state, IconicState, 1 );
}
XIconifyWindow( qt_xdisplay(), win, qt_xscreen() );
@@ -699,7 +699,7 @@ void KWin::deIconifyWindow( WId win, bool animation )
#ifdef Q_WS_X11
if ( !animation )
{
- kwin_net_create_atoms();
+ twin_net_create_atoms();
sendClientMessageToRoot( win, kde_wm_change_state, NormalState, 1 );
}
XMapWindow( qt_xdisplay(), win );
@@ -1245,10 +1245,10 @@ TQString KWin::readNameProperty( WId win, unsigned long atom )
#ifdef Q_WS_X11
if ( XGetTextProperty( qt_xdisplay(), win, &tp, atom ) != 0 && tp.value != NULL )
{
- if (!kwin_UTF8_STRING)
- kwin_UTF8_STRING = XInternAtom( qt_xdisplay(), "UTF8_STRING", False);
+ if (!twin_UTF8_STRING)
+ twin_UTF8_STRING = XInternAtom( qt_xdisplay(), "UTF8_STRING", False);
- if ( tp.encoding == kwin_UTF8_STRING ) {
+ if ( tp.encoding == twin_UTF8_STRING ) {
result = TQString::fromUtf8 ( (const char*) tp.value );
}
else if ( XmbTextPropertyToTextList( qt_xdisplay(), &tp, &text, &count) == Success &&
diff --git a/tdecore/kwin.h b/tdecore/kwin.h
index d3df42bd6..e8f00f44a 100644
--- a/tdecore/kwin.h
+++ b/tdecore/kwin.h
@@ -81,7 +81,7 @@ public:
* and normal applications are forbidden to use it.
*
* In case of problems, consult the KWin README in the kdebase
- * package (kdebase/kwin/README), or ask on the kwin@kde.org
+ * package (kdebase/twin/README), or ask on the twin@kde.org
* mailing list.
*
* @param win the id of the window to make active
diff --git a/tdecore/kwinmodule.h b/tdecore/kwinmodule.h
index 261449a16..afde02597 100644
--- a/tdecore/kwinmodule.h
+++ b/tdecore/kwinmodule.h
@@ -17,7 +17,7 @@
Boston, MA 02110-1301, USA.
*/
/*
- * kwinmodule.h. Part of the KDE project.
+ * twinmodule.h. Part of the KDE project.
*/
#ifndef KWINMODULE_H
@@ -220,7 +220,7 @@ public:
bool showingDesktop() const;
/**
- * Informs kwin via dcop to not manage a window with the
+ * Informs twin via dcop to not manage a window with the
* specified @p title.
*
* Useful for swallowing legacy applications, for example java
diff --git a/tdecore/tests/kstddirstest.cpp b/tdecore/tests/kstddirstest.cpp
index fa797d665..69e9a0200 100644
--- a/tdecore/tests/kstddirstest.cpp
+++ b/tdecore/tests/kstddirstest.cpp
@@ -43,9 +43,9 @@ int main(int argc, char **argv)
kdDebug() << "docs " << (*it).ascii() << endl;
}
- list = t.findDirs("data", "kwin");
+ list = t.findDirs("data", "twin");
for (TQStringList::ConstIterator it = list.begin(); it != list.end(); ++it) {
- kdDebug() << "kwin dirs " << (*it).ascii() << endl;
+ kdDebug() << "twin dirs " << (*it).ascii() << endl;
}
kdDebug() << "hit " << t.findResourceDir("config", "kcmdisplayrc") << endl;
diff --git a/tdecore/kwinmodule.cpp b/tdecore/kwinmodule.cpp
index f113570db..72dc0c5b5 100644
--- a/tdecore/kwinmodule.cpp
+++ b/tdecore/kwinmodule.cpp
@@ -23,8 +23,8 @@
#include <tqwidget.h>
#ifdef Q_WS_X11 //FIXME
-#include "kwinmodule.h"
-#include "kwin.h"
+#include "twinmodule.h"
+#include "twin.h"
#include <X11/Xatom.h>
#include "kapplication.h"
#include "kdebug.h"
@@ -114,13 +114,13 @@ public:
};
KWinModule::KWinModule( TQObject* parent )
- : TQObject( parent, "kwin_module" )
+ : TQObject( parent, "twin_module" )
{
init(INFO_ALL);
}
KWinModule::KWinModule( TQObject* parent, int what )
- : TQObject( parent, "kwin_module" )
+ : TQObject( parent, "twin_module" )
{
init(what);
}
@@ -186,7 +186,7 @@ TQSize KWinModulePrivate::numberOfViewports(int desktop) const
TQSize s(netdesktop.width / TQApplication::desktop()->width(),
netdesktop.height / TQApplication::desktop()->height());
// workaround some kwin bugs
if (s.width() < 1) s.setWidth(1);
if (s.height() < 1) s.setHeight(1);
return s;
@@ -474,9 +474,9 @@ void KWinModule::doNotManage( const TQString& title )
TQCString replyType;
TQDataStream arg(data, IO_WriteOnly);
arg << title;
- kapp->dcopClient()->call("kwin", "", "doNotManage(TQString)",
+ kapp->dcopClient()->call("twin", "", "doNotManage(TQString)",
data, replyType, replyData);
}
-#include "kwinmodule.moc"
+#include "twinmodule.moc"
#endif
@@ -186,7 +186,7 @@ TQSize KWinModulePrivate::numberOfViewports(int desktop) const
TQSize s(netdesktop.width / TQApplication::desktop()->width(),
netdesktop.height / TQApplication::desktop()->height());
- // workaround some kwin bugs
+ // workaround some twin bugs
if (s.width() < 1) s.setWidth(1);
if (s.height() < 1) s.setHeight(1);